summaryrefslogtreecommitdiff
path: root/lib/chef/run_context.rb
diff options
context:
space:
mode:
authortyler-ball <tyleraball@gmail.com>2014-12-02 09:30:45 -0800
committertyler-ball <tyleraball@gmail.com>2014-12-17 18:52:20 -0800
commit19f2c6e437642db0c03b193349b13d04636cb8ee (patch)
tree480eb5a24f477881621975d49869b6e78263adea /lib/chef/run_context.rb
parent2b3c252f5cad689debce640f01db9705f3c57d22 (diff)
downloadchef-19f2c6e437642db0c03b193349b13d04636cb8ee.tar.gz
Updating to use audit syntax rather than control
Diffstat (limited to 'lib/chef/run_context.rb')
-rw-r--r--lib/chef/run_context.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/chef/run_context.rb b/lib/chef/run_context.rb
index a724789d3c..d14035da2f 100644
--- a/lib/chef/run_context.rb
+++ b/lib/chef/run_context.rb
@@ -50,8 +50,8 @@ class Chef
# recipes, which is triggered by #load. (See also: CookbookCompiler)
attr_accessor :resource_collection
- # The list of control groups to execute during the audit phase
- attr_accessor :controls
+ # The list of audits (control groups) to execute during the audit phase
+ attr_accessor :audits
# A Hash containing the immediate notifications triggered by resources
# during the converge phase of the chef run.
@@ -76,7 +76,7 @@ class Chef
@node = node
@cookbook_collection = cookbook_collection
@resource_collection = Chef::ResourceCollection.new
- @controls = {}
+ @audits = {}
@immediate_notification_collection = Hash.new {|h,k| h[k] = []}
@delayed_notification_collection = Hash.new {|h,k| h[k] = []}
@definitions = Hash.new